#' Environmental Data for Modelling from station DESN025 in Leipzig-Mitte.
#'
#' A dataset containing environmental measurements collected at station in
#' Leipzig Mitte with observations of different environmental components over
#' time. This data is used for environmental modelling tasks, including
#' meteorological variables and other targets.
#'
#' @format ## sample_data_DESN025
#' A data table with the following columns:
#' \describe{
#'   \item{Station}{Station identifier where the data was collected.}
#'   \item{Komponente}{The environmental component being measured
#'        (e.g., temperature, NO2).}
#'   \item{Wert}{The measured value of the component.}
#'   \item{date}{The timestamp for the observation, formatted as a Date-Time
#'   object in the format
#'          \code{"YYYY-MM-DD HH:MM:SS"} (e.g., "2010-01-01 07:00:00").}
#'   \item{Komponente_txt}{A textual description or label for the component.}
#' }
#'
#' The dataset is structured in a long format and is prepared for further
#' transformation into a wide format for modelling.
#'
#' @source Umweltbundesamt
#' @examples
#' \dontrun{
#' params <- load_params("path/to/params.yaml")
#' dt_prepared <- prepare_data_for_modelling(sample_data_DESN025, params)
#' }
"sample_data_DESN025"
